%%%%%%%%%%%%%%%%%%%%
% Exemplo de Utilizao de Diferenas Finitas
% Professor David Roza Jos
% Transferncia de Calor - Engenharia Mecnica
% Instituto Federal Catarinense - Campus Luzerna
% 17/03/2016
%%%%%%%%%%%%%%%%%%%%
clear all
close all
clc
format long

%%%%%%% %%%% %%%%%%%%
% DADOS DO PROGRAMA %
%%%%%%% %%%% %%%%%%%%

%Entrada de dados
DeltaX = 1e-3;          %DeltaX em metros.
DeltaY = 1e-3;          %DeltaY em metros.
Lx = 3e-3;              %Comprimento em X.
Ly = 2e-3;              %Comprimento em Y.
NNx = Lx/DeltaX + 1;    %Numero de ns em X.
NNy = Ly/DeltaY + 1;    %Numero de ns em Y.
ResMax = 1e-6;          %Valor do resduo
Res = 1;                %Valor inicial do resduo
iter = 0;               %Iterao inicial
k = 24;                 %W/mK
h = 500;                 %W/mK
Ta = 200;                %C
Tinf = 15;              %C
Cte1 = 2*h*DeltaX*Tinf/k;    %Cte1
Cte2 = h*DeltaX/k;      %Cte2

%Alocao de matrizes
T1=zeros(NNy,NNx);
T2=zeros(NNy,NNx);
Dif=zeros(NNy,NNx);
VecRes1=zeros(100000,1);
VecRes2=zeros(100000,1);

%Acelerao de convergncia
n=1; %1 Acelera, 0 No acelera
if n==0
    for i=1:NNy
        for j=1:NNx
            T1(i,j)=(Ta+Tinf)/2;
            T2(i,j)=(Ta+Tinf)/2;
        end
    end
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% IMPOSIO DE CONDIES DE CONTORNO %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

for j=1:NNx
    T1(NNy,j)=Ta;
    T2(NNy,j)=Ta;
end

%%%%%%%%%%%%%%%%%%%%%%
% PROCESSO ITERATIVO %
%%%%%%%%%%%%%%%%%%%%%%

while (Res >= ResMax)
    
    iter=iter+1;
    
    %Ns do caso 1
    T2(2,2) = (T1(1,2)+T1(2,1)+T1(3,2)+T1(2,3))/4;
    T2(2,3) = (T1(1,3)+T1(2,2)+T1(3,3)+T1(2,4))/4;
    
    %Ns do caso 4
    T2(2,1) = ((2*T1(2,2) + T1(1,1) + T1(3,1)) + Cte1)/(2*(Cte2+2));
    T2(1,2) = ((2*T1(2,2) + T1(1,1) + T1(1,3)) + Cte1)/(2*(Cte2+2));
    T2(1,3) = ((2*T1(2,3) + T1(1,2) + T1(1,4)) + Cte1)/(2*(Cte2+2));
    T2(2,4) = ((2*T1(2,3) + T1(1,4) + T1(3,4)) + Cte1)/(2*(Cte2+2));
    
    %Ns do caso 5
    T2(1,1) = (T1(2,1)+T1(1,2) + Cte1)/(2*(Cte2+1));
    T2(1,4) = (T1(1,3)+T1(2,4) + Cte1)/(2*(Cte2+1));
    
    

    Dif=abs(T2-T1);
    Res=max(Dif(:));
    T1=T2;
    
    VecRes1(iter,1)=Res;
    VecRes2(iter,1)=iter;
    
end

VecRes1 = VecRes1(1:iter);
VecRes2 = VecRes2(1:iter);

%%%%%%%%%%%%%
% PLOTAGENS %
%%%%%%%%%%%%%

%Plot do grid
mesh(T1)

%Plot do resduo
figure
semilogy(VecRes2(:,1),VecRes1(:,1),'-k','LineWidth',2);
title('Resduo X Iterao');