function xb = incsearch(func,xmin,xmax,ns)
% incsearch: busca incremental do intervalo de raizes
%   xb = incsearch(func,xmin,xmax,ns):
%      encontra o intervalo onde uma raiz esta
%      atraves da troca de sinais da funcao
% input:
%   func = nome da funcao
%   xmin, xmax = extremos da faixa de busca
%   ns = numero de intervalos (padrao = 50)
% output:
%   xb(k,1) e o valor inferior da k-esima mudanca de sinal
%   xb(k,2) e o valor superior da k-esima mudanca de sinal
%   Se nenhum intervalo e encontrado, xb = [].
if nargin < 3, error('ao menos 3 argumentos necessarios'), end
if nargin < 4, ns = 50; end %se ns nao fornecido, definir 50
% Busca Incremental
x = linspace(xmin,xmax,ns);
f = func(x);
nb = 0; xb = []; %xb eh nulo exceto se for detectada mudanca de sinal
for k = 1:length(x)-1
    if sign(f(k)) ~= sign(f(k+1)) %procura por mudanca de sinal
        nb = nb + 1;
        xb(nb,1) = x(k);
        xb(nb,2) = x(k+1);
    end
end
if isempty(xb)    %mostrar que intervalos nao foram encontrados
    disp('nenhum intervalo encontrado')
    disp('revise a faixa de busca ou aumente ns')
else
    disp('quantidade de intervalos:') %mostrar numero de intervalos
    disp(nb)
end